@@ -39,7 +39,6 @@
  *			Result Value Tree interfaces			*
  *									*
  ************************************************************************/
-
 /**
  * xsltCreateRVT:
  * @ctxt:  an XSLT transformation context
@@ -471,7 +470,6 @@ xsltEvalVariable(xsltTransformContextPtr ctxt, xsltStackElemPtr elem,
 	     * Tag the subtree for removal once consumed
 	     */
 	    xsltRegisterTmpRVT(ctxt, container);
-
 	    oldoutput = ctxt->output;
 	    ctxt->output = container;
 	    oldInsert = ctxt->insert;
@@ -606,7 +604,10 @@ xsltEvalGlobalVariable(xsltStackElemPtr elem, xsltTransformContextPtr ctxt) {
 	     * Tag the subtree for removal once consumed
 	     */
 	    xsltRegisterTmpRVT(ctxt, container);
-
+	    /*
+	     * Save a pointer to the global variable for later cleanup
+	     */
+	    container->_private = elem;
 	    oldoutput = ctxt->output;
 	    ctxt->output = container;
 	    oldInsert = ctxt->insert;
@@ -690,10 +691,9 @@ xsltEvalGlobalVariables(xsltTransformContextPtr ctxt) {
 		    xmlHashLookup2(ctxt->globalVars,
 		                 elem->name, elem->nameURI);
 	    if (def == NULL) {
-		int res;
 
 		def = xsltCopyStackElem(elem);
-		res = xmlHashAddEntry2(ctxt->globalVars,
+		xmlHashAddEntry2(ctxt->globalVars,
 				 elem->name, elem->nameURI, def);
 	    } else if ((elem->comp != NULL) &&
 		       (elem->comp->type == XSLT_FUNC_VARIABLE)) {
