@@ -36,18 +36,6 @@ libxslt_xsltParseStylesheetImportedDoc(ATTRIBUTE_UNUSED PyObject *self, PyObject
     return(py_retval);
 }
 
-PyObject *
-libxslt_xsltCalibrateAdjust(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    long delta;
-
-    if (!PyArg_ParseTuple(args, (char *)"i:xsltCalibrateAdjust", &delta))
-        return(NULL);
-
-    xsltCalibrateAdjust(delta);
-    Py_INCREF(Py_None);
-    return(Py_None);
-}
-
 PyObject *
 libxslt_xsltGenerateIdFunction(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     xmlXPathParserContextPtr ctxt;
@@ -64,42 +52,20 @@ libxslt_xsltGenerateIdFunction(ATTRIBUTE_UNUSED PyObject *self, PyObject *args)
 }
 
 PyObject *
-libxslt_xsltApplyStripSpaces(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    xsltTransformContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-    xmlNodePtr node;
-    PyObject *pyobj_node;
-
-    if (!PyArg_ParseTuple(args, (char *)"OO:xsltApplyStripSpaces", &pyobj_ctxt, &pyobj_node))
-        return(NULL);
-    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
-    node = (xmlNodePtr) PyxmlNode_Get(pyobj_node);
-
-    xsltApplyStripSpaces(ctxt, node);
-    Py_INCREF(Py_None);
-    return(Py_None);
-}
-
-PyObject *
-libxslt_xsltAttrListTemplateProcess(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    PyObject *py_retval;
-    xmlAttrPtr c_retval;
-    xsltTransformContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-    xmlNodePtr target;
-    PyObject *pyobj_target;
-    xmlAttrPtr cur;
+libxslt_xsltParseGlobalParam(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    xsltStylesheetPtr style;
+    PyObject *pyobj_style;
+    xmlNodePtr cur;
     PyObject *pyobj_cur;
 
-    if (!PyArg_ParseTuple(args, (char *)"OOO:xsltAttrListTemplateProcess", &pyobj_ctxt, &pyobj_target, &pyobj_cur))
+    if (!PyArg_ParseTuple(args, (char *)"OO:xsltParseGlobalParam", &pyobj_style, &pyobj_cur))
         return(NULL);
-    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
-    target = (xmlNodePtr) PyxmlNode_Get(pyobj_target);
-    cur = (xmlAttrPtr) PyxmlNode_Get(pyobj_cur);
+    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
+    cur = (xmlNodePtr) PyxmlNode_Get(pyobj_cur);
 
-    c_retval = xsltAttrListTemplateProcess(ctxt, target, cur);
-    py_retval = libxml_xmlNodePtrWrap((xmlNodePtr) c_retval);
-    return(py_retval);
+    xsltParseGlobalParam(style, cur);
+    Py_INCREF(Py_None);
+    return(Py_None);
 }
 
 PyObject *
@@ -139,6 +105,22 @@ libxslt_xsltMessage(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     return(Py_None);
 }
 
+PyObject *
+libxslt_xsltCreateRVT(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    PyObject *py_retval;
+    xmlDocPtr c_retval;
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+
+    if (!PyArg_ParseTuple(args, (char *)"O:xsltCreateRVT", &pyobj_ctxt))
+        return(NULL);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+
+    c_retval = xsltCreateRVT(ctxt);
+    py_retval = libxml_xmlDocPtrWrap((xmlDocPtr) c_retval);
+    return(py_retval);
+}
+
 PyObject *
 libxslt_xsltParseStylesheetProcess(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     PyObject *py_retval;
@@ -513,27 +495,6 @@ libxslt_xsltSaveResultToFile(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     return(py_retval);
 }
 
-PyObject *
-libxslt_xsltApplyAttributeSet(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    xsltTransformContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-    xmlNodePtr node;
-    PyObject *pyobj_node;
-    xmlNodePtr inst;
-    PyObject *pyobj_inst;
-    xmlChar * attributes;
-
-    if (!PyArg_ParseTuple(args, (char *)"OOOz:xsltApplyAttributeSet", &pyobj_ctxt, &pyobj_node, &pyobj_inst, &attributes))
-        return(NULL);
-    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
-    node = (xmlNodePtr) PyxmlNode_Get(pyobj_node);
-    inst = (xmlNodePtr) PyxmlNode_Get(pyobj_inst);
-
-    xsltApplyAttributeSet(ctxt, node, inst, attributes);
-    Py_INCREF(Py_None);
-    return(Py_None);
-}
-
 PyObject *
 libxslt_xsltParseGlobalVariable(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     xsltStylesheetPtr style;
@@ -690,6 +651,28 @@ libxslt_xsltFunctionNodeSet(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     return(Py_None);
 }
 
+PyObject *
+libxslt_xsltAttrListTemplateProcess(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    PyObject *py_retval;
+    xmlAttrPtr c_retval;
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+    xmlNodePtr target;
+    PyObject *pyobj_target;
+    xmlAttrPtr cur;
+    PyObject *pyobj_cur;
+
+    if (!PyArg_ParseTuple(args, (char *)"OOO:xsltAttrListTemplateProcess", &pyobj_ctxt, &pyobj_target, &pyobj_cur))
+        return(NULL);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+    target = (xmlNodePtr) PyxmlNode_Get(pyobj_target);
+    cur = (xmlAttrPtr) PyxmlNode_Get(pyobj_cur);
+
+    c_retval = xsltAttrListTemplateProcess(ctxt, target, cur);
+    py_retval = libxml_xmlNodePtrWrap((xmlNodePtr) c_retval);
+    return(py_retval);
+}
+
 PyObject *
 libxslt_xsltCleanupTemplates(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     xsltStylesheetPtr style;
@@ -705,35 +688,31 @@ libxslt_xsltCleanupTemplates(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
 }
 
 PyObject *
-libxslt_xsltCheckExtPrefix(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    PyObject *py_retval;
-    int c_retval;
-    xsltStylesheetPtr style;
-    PyObject *pyobj_style;
-    xmlChar * prefix;
+libxslt_xsltDocumentFunction(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    xmlXPathParserContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+    int nargs;
 
-    if (!PyArg_ParseTuple(args, (char *)"Oz:xsltCheckExtPrefix", &pyobj_style, &prefix))
+    if (!PyArg_ParseTuple(args, (char *)"Oi:xsltDocumentFunction", &pyobj_ctxt, &nargs))
         return(NULL);
-    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
+    ctxt = (xmlXPathParserContextPtr) PyxmlXPathParserContext_Get(pyobj_ctxt);
 
-    c_retval = xsltCheckExtPrefix(style, prefix);
-    py_retval = libxml_intWrap((int) c_retval);
-    return(py_retval);
+    xsltDocumentFunction(ctxt, nargs);
+    Py_INCREF(Py_None);
+    return(Py_None);
 }
 
 PyObject *
-libxslt_xsltParseStylesheetOutput(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    xsltStylesheetPtr style;
-    PyObject *pyobj_style;
-    xmlNodePtr cur;
-    PyObject *pyobj_cur;
+libxslt_xsltElementAvailableFunction(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    xmlXPathParserContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+    int nargs;
 
-    if (!PyArg_ParseTuple(args, (char *)"OO:xsltParseStylesheetOutput", &pyobj_style, &pyobj_cur))
+    if (!PyArg_ParseTuple(args, (char *)"Oi:xsltElementAvailableFunction", &pyobj_ctxt, &nargs))
         return(NULL);
-    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
-    cur = (xmlNodePtr) PyxmlNode_Get(pyobj_cur);
+    ctxt = (xmlXPathParserContextPtr) PyxmlXPathParserContext_Get(pyobj_ctxt);
 
-    xsltParseStylesheetOutput(style, cur);
+    xsltElementAvailableFunction(ctxt, nargs);
     Py_INCREF(Py_None);
     return(Py_None);
 }
@@ -777,18 +756,6 @@ libxslt_xsltFunctionAvailableFunction(ATTRIBUTE_UNUSED PyObject *self, PyObject
     return(Py_None);
 }
 
-PyObject *
-libxslt_xsltSetXIncludeDefault(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    int xinclude;
-
-    if (!PyArg_ParseTuple(args, (char *)"i:xsltSetXIncludeDefault", &xinclude))
-        return(NULL);
-
-    xsltSetXIncludeDefault(xinclude);
-    Py_INCREF(Py_None);
-    return(Py_None);
-}
-
 PyObject *
 libxslt_xsltFormatNumberFunction(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     xmlXPathParserContextPtr ctxt;
@@ -882,21 +849,19 @@ libxslt_xsltAddKey(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
 }
 
 PyObject *
-libxslt_xsltNewTransformContext(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+libxslt_xsltCheckExtPrefix(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     PyObject *py_retval;
-    xsltTransformContextPtr c_retval;
+    int c_retval;
     xsltStylesheetPtr style;
     PyObject *pyobj_style;
-    xmlDocPtr doc;
-    PyObject *pyobj_doc;
+    xmlChar * prefix;
 
-    if (!PyArg_ParseTuple(args, (char *)"OO:xsltNewTransformContext", &pyobj_style, &pyobj_doc))
+    if (!PyArg_ParseTuple(args, (char *)"Oz:xsltCheckExtPrefix", &pyobj_style, &prefix))
         return(NULL);
     style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
-    doc = (xmlDocPtr) PyxmlNode_Get(pyobj_doc);
 
-    c_retval = xsltNewTransformContext(style, doc);
-    py_retval = libxslt_xsltTransformContextPtrWrap((xsltTransformContextPtr) c_retval);
+    c_retval = xsltCheckExtPrefix(style, prefix);
+    py_retval = libxml_intWrap((int) c_retval);
     return(py_retval);
 }
 
@@ -935,19 +900,45 @@ libxslt_xsltAttrTemplateValueProcessNode(ATTRIBUTE_UNUSED PyObject *self, PyObje
 }
 
 PyObject *
-libxslt_xsltFreeTemplateHashes(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    xsltStylesheetPtr style;
-    PyObject *pyobj_style;
+libxslt_xsltApplyAttributeSet(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+    xmlNodePtr node;
+    PyObject *pyobj_node;
+    xmlNodePtr inst;
+    PyObject *pyobj_inst;
+    xmlChar * attributes;
 
-    if (!PyArg_ParseTuple(args, (char *)"O:xsltFreeTemplateHashes", &pyobj_style))
+    if (!PyArg_ParseTuple(args, (char *)"OOOz:xsltApplyAttributeSet", &pyobj_ctxt, &pyobj_node, &pyobj_inst, &attributes))
         return(NULL);
-    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+    node = (xmlNodePtr) PyxmlNode_Get(pyobj_node);
+    inst = (xmlNodePtr) PyxmlNode_Get(pyobj_inst);
 
-    xsltFreeTemplateHashes(style);
+    xsltApplyAttributeSet(ctxt, node, inst, attributes);
     Py_INCREF(Py_None);
     return(Py_None);
 }
 
+PyObject *
+libxslt_xsltRegisterTmpRVT(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    PyObject *py_retval;
+    int c_retval;
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+    xmlDocPtr RVT;
+    PyObject *pyobj_RVT;
+
+    if (!PyArg_ParseTuple(args, (char *)"OO:xsltRegisterTmpRVT", &pyobj_ctxt, &pyobj_RVT))
+        return(NULL);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+    RVT = (xmlDocPtr) PyxmlNode_Get(pyobj_RVT);
+
+    c_retval = xsltRegisterTmpRVT(ctxt, RVT);
+    py_retval = libxml_intWrap((int) c_retval);
+    return(py_retval);
+}
+
 PyObject *
 libxslt_xsltUnregisterExtModuleTopLevel(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     PyObject *py_retval;
@@ -1031,26 +1022,23 @@ libxslt_xsltTransformGetContext(ATTRIBUTE_UNUSED PyObject *self, PyObject *args)
 }
 
 PyObject *
-libxslt_xsltRegisterTestModule(ATTRIBUTE_UNUSED PyObject *self,ATTRIBUTE_UNUSED  PyObject *args) {
+libxslt_xsltFreeRVTs(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
 
-    xsltRegisterTestModule();
+    if (!PyArg_ParseTuple(args, (char *)"O:xsltFreeRVTs", &pyobj_ctxt))
+        return(NULL);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+
+    xsltFreeRVTs(ctxt);
     Py_INCREF(Py_None);
     return(Py_None);
 }
 
 PyObject *
-libxslt_xsltParseGlobalParam(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    xsltStylesheetPtr style;
-    PyObject *pyobj_style;
-    xmlNodePtr cur;
-    PyObject *pyobj_cur;
+libxslt_xsltRegisterTestModule(ATTRIBUTE_UNUSED PyObject *self,ATTRIBUTE_UNUSED  PyObject *args) {
 
-    if (!PyArg_ParseTuple(args, (char *)"OO:xsltParseGlobalParam", &pyobj_style, &pyobj_cur))
-        return(NULL);
-    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
-    cur = (xmlNodePtr) PyxmlNode_Get(pyobj_cur);
-
-    xsltParseGlobalParam(style, cur);
+    xsltRegisterTestModule();
     Py_INCREF(Py_None);
     return(Py_None);
 }
@@ -1157,6 +1145,20 @@ libxslt_xsltTransformGetOutputDoc(ATTRIBUTE_UNUSED PyObject *self, PyObject *arg
     return(py_retval);
 }
 
+PyObject *
+libxslt_xsltFreeTemplateHashes(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    xsltStylesheetPtr style;
+    PyObject *pyobj_style;
+
+    if (!PyArg_ParseTuple(args, (char *)"O:xsltFreeTemplateHashes", &pyobj_style))
+        return(NULL);
+    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
+
+    xsltFreeTemplateHashes(style);
+    Py_INCREF(Py_None);
+    return(Py_None);
+}
+
 PyObject *
 libxslt_xsltFreeStyleDocuments(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     xsltStylesheetPtr style;
@@ -1187,37 +1189,6 @@ libxslt_xsltStylesheetGetEncoding(ATTRIBUTE_UNUSED PyObject *self, PyObject *arg
     return(py_retval);
 }
 
-PyObject *
-libxslt_xsltElementAvailableFunction(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    xmlXPathParserContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-    int nargs;
-
-    if (!PyArg_ParseTuple(args, (char *)"Oi:xsltElementAvailableFunction", &pyobj_ctxt, &nargs))
-        return(NULL);
-    ctxt = (xmlXPathParserContextPtr) PyxmlXPathParserContext_Get(pyobj_ctxt);
-
-    xsltElementAvailableFunction(ctxt, nargs);
-    Py_INCREF(Py_None);
-    return(Py_None);
-}
-
-PyObject *
-libxslt_xsltTransformGetStyle(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    PyObject *py_retval;
-    xsltStylesheetPtr c_retval;
-    xsltTransformContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-
-    if (!PyArg_ParseTuple(args, (char *)"O:xsltTransformGetStyle", &pyobj_ctxt))
-        return(NULL);
-    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
-
-    c_retval = ctxt->style;
-    py_retval = libxslt_xsltStylesheetPtrWrap((xsltStylesheetPtr) c_retval);
-    return(py_retval);
-}
-
 PyObject *
 libxslt_xsltTransformGetMode(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     PyObject *py_retval;
@@ -1234,20 +1205,6 @@ libxslt_xsltTransformGetMode(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     return(py_retval);
 }
 
-PyObject *
-libxslt_xsltFreeTransformContext(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    xsltTransformContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-
-    if (!PyArg_ParseTuple(args, (char *)"O:xsltFreeTransformContext", &pyobj_ctxt))
-        return(NULL);
-    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
-
-    xsltFreeTransformContext(ctxt);
-    Py_INCREF(Py_None);
-    return(Py_None);
-}
-
 PyObject *
 libxslt_xsltFreeExts(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     xsltStylesheetPtr style;
@@ -1279,6 +1236,23 @@ libxslt_xsltParseStylesheetParam(ATTRIBUTE_UNUSED PyObject *self, PyObject *args
     return(Py_None);
 }
 
+PyObject *
+libxslt_xsltParseStylesheetOutput(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    xsltStylesheetPtr style;
+    PyObject *pyobj_style;
+    xmlNodePtr cur;
+    PyObject *pyobj_cur;
+
+    if (!PyArg_ParseTuple(args, (char *)"OO:xsltParseStylesheetOutput", &pyobj_style, &pyobj_cur))
+        return(NULL);
+    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
+    cur = (xmlNodePtr) PyxmlNode_Get(pyobj_cur);
+
+    xsltParseStylesheetOutput(style, cur);
+    Py_INCREF(Py_None);
+    return(Py_None);
+}
+
 PyObject *
 libxslt_xsltFreeStylePreComps(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     xsltStylesheetPtr style;
@@ -1471,6 +1445,25 @@ libxslt_xsltInitCtxtExts(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     return(py_retval);
 }
 
+PyObject *
+libxslt_xsltRegisterPersistRVT(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    PyObject *py_retval;
+    int c_retval;
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+    xmlDocPtr RVT;
+    PyObject *pyobj_RVT;
+
+    if (!PyArg_ParseTuple(args, (char *)"OO:xsltRegisterPersistRVT", &pyobj_ctxt, &pyobj_RVT))
+        return(NULL);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+    RVT = (xmlDocPtr) PyxmlNode_Get(pyobj_RVT);
+
+    c_retval = xsltRegisterPersistRVT(ctxt, RVT);
+    py_retval = libxml_intWrap((int) c_retval);
+    return(py_retval);
+}
+
 PyObject *
 libxslt_xsltResolveStylesheetAttributeSet(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     xsltStylesheetPtr style;
@@ -1485,20 +1478,6 @@ libxslt_xsltResolveStylesheetAttributeSet(ATTRIBUTE_UNUSED PyObject *self, PyObj
     return(Py_None);
 }
 
-PyObject *
-libxslt_xsltRegisterAllElement(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    xsltTransformContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-
-    if (!PyArg_ParseTuple(args, (char *)"O:xsltRegisterAllElement", &pyobj_ctxt))
-        return(NULL);
-    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
-
-    xsltRegisterAllElement(ctxt);
-    Py_INCREF(Py_None);
-    return(Py_None);
-}
-
 PyObject *
 libxslt_xsltTransformGetOutputURI(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     PyObject *py_retval;
@@ -1696,12 +1675,18 @@ libxslt_xsltRegisterAllExtras(ATTRIBUTE_UNUSED PyObject *self,ATTRIBUTE_UNUSED
 }
 
 PyObject *
-libxslt_xsltGetXIncludeDefault(ATTRIBUTE_UNUSED PyObject *self,ATTRIBUTE_UNUSED  PyObject *args) {
+libxslt_xsltTransformGetStyle(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     PyObject *py_retval;
-    int c_retval;
+    xsltStylesheetPtr c_retval;
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
 
-    c_retval = xsltGetXIncludeDefault();
-    py_retval = libxml_intWrap((int) c_retval);
+    if (!PyArg_ParseTuple(args, (char *)"O:xsltTransformGetStyle", &pyobj_ctxt))
+        return(NULL);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+
+    c_retval = ctxt->style;
+    py_retval = libxslt_xsltStylesheetPtrWrap((xsltStylesheetPtr) c_retval);
     return(py_retval);
 }
 
@@ -1735,6 +1720,41 @@ libxslt_xsltStylesheetGetDoctypeSystem(ATTRIBUTE_UNUSED PyObject *self, PyObject
     return(py_retval);
 }
 
+PyObject *
+libxslt_xsltCalibrateAdjust(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    long delta;
+
+    if (!PyArg_ParseTuple(args, (char *)"i:xsltCalibrateAdjust", &delta))
+        return(NULL);
+
+    xsltCalibrateAdjust(delta);
+    Py_INCREF(Py_None);
+    return(Py_None);
+}
+
+PyObject *
+libxslt_xsltDebug(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+    xmlNodePtr node;
+    PyObject *pyobj_node;
+    xmlNodePtr inst;
+    PyObject *pyobj_inst;
+    xsltStylePreCompPtr comp;
+    PyObject *pyobj_comp;
+
+    if (!PyArg_ParseTuple(args, (char *)"OOOO:xsltDebug", &pyobj_ctxt, &pyobj_node, &pyobj_inst, &pyobj_comp))
+        return(NULL);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+    node = (xmlNodePtr) PyxmlNode_Get(pyobj_node);
+    inst = (xmlNodePtr) PyxmlNode_Get(pyobj_inst);
+    comp = (xsltStylePreCompPtr) PycompiledStyle_Get(pyobj_comp);
+
+    xsltDebug(ctxt, node, inst, comp);
+    Py_INCREF(Py_None);
+    return(Py_None);
+}
+
 PyObject *
 libxslt_xsltStylesheetGetMethodURI(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     PyObject *py_retval;
@@ -1751,21 +1771,6 @@ libxslt_xsltStylesheetGetMethodURI(ATTRIBUTE_UNUSED PyObject *self, PyObject *ar
     return(py_retval);
 }
 
-PyObject *
-libxslt_xsltDocumentFunction(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
-    xmlXPathParserContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-    int nargs;
-
-    if (!PyArg_ParseTuple(args, (char *)"Oi:xsltDocumentFunction", &pyobj_ctxt, &nargs))
-        return(NULL);
-    ctxt = (xmlXPathParserContextPtr) PyxmlXPathParserContext_Get(pyobj_ctxt);
-
-    xsltDocumentFunction(ctxt, nargs);
-    Py_INCREF(Py_None);
-    return(Py_None);
-}
-
 PyObject *
 libxslt_xsltParseStylesheetDoc(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     PyObject *py_retval;
